@@ -76,20 +76,25 @@ class FrameVersions:
         self._queue = queue
         self._device = device
 
+    def _make_request(self, frame_type: int, version: int) -> None:
+        """Make update request and put it into write queue."""
+        try:
+            request = factory(
+                get_frame_handler(frame_type), recipient=self._device.address
+            )
+        except UnknownFrameError:
+            # Ignore unknown frames in version list.
+            return
+
+        self._queue.put_nowait(request)
+        self.versions[frame_type] = version
+
     def update(self, frame_versions: VersionsInfoType) -> None:
         """Check versions and fetch outdated frames."""
         for frame_type, version in frame_versions.items():
             if frame_type not in self.versions or self.versions[frame_type] != version:
                 # We don't have this frame or it's version has changed.
-                try:
-                    request = factory(
-                        get_frame_handler(frame_type), recipient=self._device.address
-                    )
-                    self._queue.put_nowait(request)
-                    self.versions[frame_type] = version
-                except UnknownFrameError:
-                    # Ignore unknown frames in version list.
-                    continue
+                self._make_request(frame_type, version)
 
     async def async_update(self, *args, **kwargs) -> None:
         """Asynchronously check versions and fetch outdated frames."""
@@ -253,10 +258,9 @@ class EcoMAX(Device):
         except IndexError:
             mixer = Mixer(mixer_number)
             mixers.append(mixer)
-
-        if (mixer_number + 1) == total_mixers:
-            # All mixers were processed, notify callbacks and getters.
-            self.set_device_data(ATTR_MIXERS, mixers)
+            if len(mixers) == total_mixers:
+                # All mixers were processed, notify callbacks and getters.
+                self.set_device_data(ATTR_MIXERS, mixers)
 
         return mixer
 
