@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
-from enum import IntEnum
+from enum import IntEnum, unique
 from typing import ClassVar, Dict, Final, List, Optional
 
 from pyplumio import util
@@ -17,72 +17,58 @@ HEADER_SIZE: Final = 7
 FRAME_TYPE_SIZE: Final = 1
 CRC_SIZE: Final = 1
 DELIMITER_SIZE: Final = 1
-ECONET_TYPE: Final = 0x30
-ECONET_VERSION: Final = 0x05
+ECONET_TYPE: Final = 48
+ECONET_VERSION: Final = 5
 
 
-class RequestTypes(IntEnum):
-    """Contains request frame types."""
+@unique
+class FrameTypes(IntEnum):
+    """Contains frame types."""
 
-    STOP_MASTER = 0x18
-    START_MASTER = 0x19
-    CHECK_DEVICE = 0x30
-    BOILER_PARAMETERS = 0x31
-    MIXER_PARAMETERS = 0x32
-    SET_BOILER_PARAMETER = 0x33
-    SET_MIXER_PARAMETER = 0x34
-    UID = 0x39
-    PASSWORD = 0x3A
-    BOILER_CONTROL = 0x3B
-    PROGRAM_VERSION = 0x40
-    DATA_SCHEMA = 0x55
-    ALERTS = 0x3D
+    REQUEST_STOP_MASTER = 24
+    REQUEST_START_MASTER = 25
+    REQUEST_CHECK_DEVICE = 48
+    REQUEST_BOILER_PARAMETERS = 49
+    REQUEST_MIXER_PARAMETERS = 50
+    REQUEST_SET_BOILER_PARAMETER = 51
+    REQUEST_SET_MIXER_PARAMETER = 52
+    REQUEST_UID = 57
+    REQUEST_PASSWORD = 58
+    REQUEST_BOILER_CONTROL = 59
+    REQUEST_ALERTS = 61
+    REQUEST_PROGRAM_VERSION = 64
+    REQUEST_DATA_SCHEMA = 85
+    RESPONSE_DEVICE_AVAILABLE = 176
+    RESPONSE_BOILER_PARAMETERS = 177
+    RESPONSE_MIXER_PARAMETERS = 178
+    RESPONSE_SET_BOILER_PARAMETER = 179
+    RESPONSE_SET_MIXER_PARAMETER = 180
+    RESPONSE_UID = 185
+    RESPONSE_PASSWORD = 186
+    RESPONSE_BOILER_CONTROL = 187
+    RESPONSE_ALERTS = 189
+    RESPONSE_PROGRAM_VERSION = 192
+    RESPONSE_DATA_SCHEMA = 213
+    MESSAGE_REGULATOR_DATA = 8
+    MESSAGE_SENSOR_DATA = 53
 
 
-REQUEST_TYPES = {
-    x.value: f"requests.{util.to_camelcase(x.name)}Request" for x in RequestTypes
-}
+def _handler_class_path(frame_type_name: str) -> str:
+    """Return handler class path from module and frame type name."""
+    module, type_name = frame_type_name.split("_", 1)
 
-
-class ResponseTypes(IntEnum):
-    """Contains response frame types."""
-
-    DEVICE_AVAILABLE = 0xB0
-    UID = 0xB9
-    BOILER_PARAMETERS = 0xB1
-    MIXER_PARAMETERS = 0xB2
-    SET_BOILER_PARAMETER = 0xB3
-    SET_MIXER_PARAMETER = 0xB4
-    PASSWORD = 0xBA
-    BOILER_CONTROL = 0xBB
-    PROGRAM_VERSION = 0xC0
-    DATA_SCHEMA = 0xD5
-    ALERTS = 0xBD
-
-
-RESPONSE_TYPES = {
-    x.value: f"responses.{util.to_camelcase(x.name)}Response" for x in ResponseTypes
-}
-
-
-class MessageTypes(IntEnum):
-    """Contains message frame types."""
-
-    REGULATOR_DATA = 0x08
-    SENSOR_DATA = 0x35
-
-
-MESSAGE_TYPES = {
-    x.value: f"messages.{util.to_camelcase(x.name)}Message" for x in MessageTypes
-}
+    return f"{module.lower()}s.{util.to_camelcase(type_name)}{module.capitalize()}"
 
 
 # Dictionary of frame handler classes indexed by frame types.
-FRAME_TYPES: Dict[int, str] = {**REQUEST_TYPES, **RESPONSE_TYPES, **MESSAGE_TYPES}
+# example: "24: requests.StopMasterRequest"
+FRAME_TYPES: Dict[int, str] = {
+    frame_type.value: _handler_class_path(frame_type.name) for frame_type in FrameTypes
+}
 
 
 def get_frame_handler(frame_type: int) -> str:
-    """Return class path for the frame type."""
+    """Return handler class path for the frame type."""
     if frame_type in FRAME_TYPES:
         return f"frames.{FRAME_TYPES[frame_type]}"
 
