@@ -27,11 +27,7 @@ class DataType(ABC):
 
     def __repr__(self) -> str:
         """Return serializable string representation of the class."""
-        return f"""{self.__class__.__name__}(
-    data={self._data!r},
-    size={self.size},
-)
-""".strip()
+        return f"{self.__class__.__name__}(data={self._data!r}, size={self.size})"
 
     def unpack(self, data: BytesType):
         """Unpack data to a given type."""
